@@ -1,6 +1,7 @@
 //! tls module
+use std::fmt::{self, Formatter};
 use std::future::Future;
-use std::io::{self, Cursor, Read};
+use std::io::{self, Cursor, Error as IoError, ErrorKind, Read};
 use std::path::Path;
 use std::pin::Pin;
 use std::task::{Context, Poll};
@@ -24,12 +25,17 @@ pub struct NativeTlsConfig {
     password: String,
 }
 
-impl std::fmt::Debug for NativeTlsConfig {
-    fn fmt(&self, f: &mut ::std::fmt::Formatter) -> ::std::fmt::Result {
+impl fmt::Debug for NativeTlsConfig {
+    fn fmt(&self, f: &mut Formatter) -> fmt::Result {
         f.debug_struct("NativeTlsConfig").finish()
     }
 }
 
+impl Default for NativeTlsConfig {
+    fn default() -> Self {
+        Self::new()
+    }
+}
 impl NativeTlsConfig {
     /// Create new `NativeTlsConfig`
     #[inline]
@@ -65,13 +71,12 @@ impl NativeTlsConfig {
 
     /// generate identity
     #[inline]
-    pub fn identity(mut self) -> Result<Identity, io::Error> {
+    pub fn identity(mut self) -> Result<Identity, IoError> {
         let mut pkcs12 = Vec::new();
         self.pkcs12
             .read_to_end(&mut pkcs12)
-            .map_err(|err| io::Error::new(io::ErrorKind::Other, err.to_string()))?;
-        Identity::from_pkcs12(&pkcs12, &self.password)
-            .map_err(|err| io::Error::new(io::ErrorKind::Other, err.to_string()))
+            .map_err(|e| IoError::new(ErrorKind::Other, e.to_string()))?;
+        Identity::from_pkcs12(&pkcs12, &self.password).map_err(|e| IoError::new(ErrorKind::Other, e.to_string()))
     }
 }
 
@@ -119,7 +124,7 @@ impl NativeTlsListener<stream::Once<Ready<Identity>>> {
     #[inline]
     pub fn try_with_config(
         config: NativeTlsConfig,
-    ) -> Result<NativeTlsListenerBuilder<stream::Once<Ready<Identity>>>, io::Error> {
+    ) -> Result<NativeTlsListenerBuilder<stream::Once<Ready<Identity>>>, IoError> {
         let identity = config.identity()?;
         Ok(Self::with_identity(identity))
     }
@@ -166,15 +171,13 @@ where
     C::Item: Into<Identity>,
 {
     type Conn = NativeTlsStream;
-    type Error = io::Error;
+    type Error = IoError;
 
     fn poll_accept(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Option<Result<Self::Conn, Self::Error>>> {
         let this = self.project();
-        if let Poll::Ready(result) = this.config_stream.poll_next(cx) {
-            if let Some(identity) = result {
-                let identity = identity.into();
-                *this.identity = Some(identity);
-            }
+        if let Poll::Ready(Some(identity)) = this.config_stream.poll_next(cx) {
+            let identity = identity.into();
+            *this.identity = Some(identity);
         }
         if let Some(identity) = this.identity {
             match ready!(Pin::new(this.incoming).poll_accept(cx)) {
@@ -186,21 +189,10 @@ where
                 _ => Poll::Ready(None),
             }
         } else {
-            Poll::Ready(Some(Err(io::Error::new(io::ErrorKind::Other, "acceptor is none"))))
+            Poll::Ready(Some(Err(IoError::new(ErrorKind::Other, "acceptor is none"))))
         }
     }
 }
-impl<C> Future for NativeTlsListener<C>
-where
-    C: Stream,
-    C::Item: Into<Identity>,
-{
-    type Output = Option<Result<NativeTlsStream, io::Error>>;
-
-    fn poll(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Self::Output> {
-        self.poll_accept(cx)
-    }
-}
 
 pin_project! {
     /// NativeTlsStream
@@ -221,9 +213,9 @@ impl Transport for NativeTlsStream {
 }
 
 impl NativeTlsStream {
-    fn new(remote_addr: SocketAddr, stream: AddrStream, identity: Identity) -> Result<Self, io::Error> {
+    fn new(remote_addr: SocketAddr, stream: AddrStream, identity: Identity) -> Result<Self, IoError> {
         let acceptor: AsyncTlsAcceptor = TlsAcceptor::new(identity)
-            .map_err(|err| io::Error::new(io::ErrorKind::Other, err.to_string()))?
+            .map_err(|e| IoError::new(ErrorKind::Other, e.to_string()))?
             .into();
         Ok(NativeTlsStream {
             // acceptor: Box::pin(acceptor),
@@ -243,7 +235,7 @@ impl AsyncRead for NativeTlsStream {
             *this.inner_stream = Some(stream);
             Pin::new(this.inner_stream.as_mut().unwrap()).poll_read(cx, buf)
         } else {
-            Poll::Ready(Err(io::Error::new(io::ErrorKind::Other, "native tls error")))
+            Poll::Ready(Err(IoError::new(ErrorKind::Other, "native tls error")))
         }
     }
 }
@@ -257,7 +249,7 @@ impl AsyncWrite for NativeTlsStream {
             *this.inner_stream = Some(stream);
             Pin::new(this.inner_stream.as_mut().unwrap()).poll_write(cx, buf)
         } else {
-            Poll::Ready(Err(io::Error::new(io::ErrorKind::Other, "native tls error")))
+            Poll::Ready(Err(IoError::new(ErrorKind::Other, "native tls error")))
         }
     }
 
@@ -269,7 +261,7 @@ impl AsyncWrite for NativeTlsStream {
             *this.inner_stream = Some(stream);
             Pin::new(this.inner_stream.as_mut().unwrap()).poll_flush(cx)
         } else {
-            Poll::Ready(Err(io::Error::new(io::ErrorKind::Other, "native tls error")))
+            Poll::Ready(Err(IoError::new(ErrorKind::Other, "native tls error")))
         }
     }
 
@@ -281,24 +273,37 @@ impl AsyncWrite for NativeTlsStream {
             *this.inner_stream = Some(stream);
             Pin::new(this.inner_stream.as_mut().unwrap()).poll_shutdown(cx)
         } else {
-            Poll::Ready(Err(io::Error::new(io::ErrorKind::Other, "native tls error")))
+            Poll::Ready(Err(IoError::new(ErrorKind::Other, "native tls error")))
         }
     }
 }
 
 #[cfg(test)]
 mod tests {
+    use futures_util::{Stream, StreamExt};
     use tokio::io::{AsyncReadExt, AsyncWriteExt};
     use tokio::net::TcpStream;
 
     use super::*;
 
+    impl<C> Stream for NativeTlsListener<C>
+    where
+        C: Stream,
+        C::Item: Into<Identity>,
+    {
+        type Item = Result<NativeTlsStream, IoError>;
+
+        fn poll_next(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Option<Self::Item>> {
+            self.poll_accept(cx)
+        }
+    }
+
     #[tokio::test]
     async fn test_native_tls_listener() {
         let addr = "127.0.0.1:7879";
-        let listener = NativeTlsListener::with_config(
+        let mut listener = NativeTlsListener::with_config(
             NativeTlsConfig::new()
-                .with_pkcs12(include_bytes!("../../../examples/certs/identity.p12").to_vec())
+                .with_pkcs12(include_bytes!("../../certs/identity.p12").to_vec())
                 .with_password("mypass"),
         )
         .bind(addr);
@@ -314,7 +319,7 @@ mod tests {
             tls_stream.write_i32(518).await.unwrap();
         });
 
-        let mut stream = listener.await.unwrap().unwrap();
+        let mut stream = listener.next().await.unwrap().unwrap();
         assert_eq!(stream.read_i32().await.unwrap(), 518);
     }
 }
