@@ -1,10 +1,10 @@
 use std::collections::HashMap;
-use std::fmt;
+use std::fmt::{self, Formatter};
 use std::sync::Arc;
 
 use once_cell::sync::Lazy;
+use parking_lot::RwLock;
 use regex::Regex;
-use std::sync::RwLock;
 
 use crate::http::Request;
 use crate::routing::{Filter, PathState};
@@ -133,7 +133,7 @@ struct CharPart<C> {
     max_width: Option<usize>,
 }
 impl<C> fmt::Debug for CharPart<C> {
-    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
+    fn fmt(&self, f: &mut Formatter<'_>) -> fmt::Result {
         write!(
             f,
             "CharPart {{ name: {:?}, min_width: {:?}, max_width: {:?} }}",
@@ -266,8 +266,9 @@ impl PathPart for RegexPart {
             let segment = url_path.splitn(2, '/').collect::<Vec<_>>()[0];
             let cap = self.regex.captures(segment).and_then(|caps| caps.get(0));
             if let Some(cap) = cap {
-                state.params.insert(self.name.clone(), cap.as_str().to_owned());
-                state.cursor += segment.len();
+                let cap = cap.as_str().to_owned();
+                state.cursor += cap.len();
+                state.params.insert(self.name.clone(), cap);
                 true
             } else {
                 false
@@ -285,7 +286,7 @@ impl PathPart for ConstPart {
             return false;
         }
         let segment = url_path.splitn(2, '/').collect::<Vec<_>>()[0];
-        if segment.contains(&self.0) {
+        if segment.starts_with(&self.0) {
             state.cursor += self.0.len();
             true
         } else {
@@ -486,9 +487,7 @@ impl PathParser {
                                 self.offset
                             ));
                         };
-                        let builders = PART_BUILDERS
-                            .read()
-                            .map_err(|_| "read PART_BUILDERS failed".to_owned())?;
+                        let builders = PART_BUILDERS.read();
                         let builder = builders
                             .get(&sign)
                             .ok_or_else(|| format!("PART_BUILDERS does not contains fn part with sign {}", sign))?
@@ -584,8 +583,8 @@ pub struct PathFilter {
 }
 
 impl fmt::Debug for PathFilter {
-    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
-        write!(f, "{}", &self.raw_value)
+    fn fmt(&self, f: &mut Formatter<'_>) -> fmt::Result {
+        write!(f, "path:{}", &self.raw_value)
     }
 }
 impl Filter for PathFilter {
@@ -611,14 +610,13 @@ impl PathFilter {
     where
         B: PartBuilder + 'static,
     {
-        PART_BUILDERS.write().unwrap().insert(name, Arc::new(Box::new(builder)));
+        let mut builders = PART_BUILDERS.write();
+        builders.insert(name, Arc::new(Box::new(builder)));
     }
     /// Register new path part regex.
     pub fn register_path_part_regex<B>(name: String, regex: Regex) {
-        PART_BUILDERS
-            .write()
-            .unwrap()
-            .insert(name, Arc::new(Box::new(RegexPartBuilder::new(regex))));
+        let mut builders = PART_BUILDERS.write();
+        builders.insert(name, Arc::new(Box::new(RegexPartBuilder::new(regex))));
     }
     /// Detect is that path is match.
     pub fn detect(&self, state: &mut PathState) -> bool {
